--[[
Copyright (c) 2010, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--
local Broker_RecZone = _G["Broker_RecZone"];

if( not Broker_RecZone ) then
    return;
end--if

--[[
"name;low;high;continent;type;faction;flags;walkpath neighbors;neighbors;transportlinks",
name can be | seperated, first is map name, after is alternates, optional displayname marked with !
flags:
    b: number of bosses    
    d: holiday that has a holiday boss
    f: flyable
    h: heroic in format hlow,high or hlow,high,bosses
    m: mountable
    p: progression
    r: comma seperated list of brackets, in the form low:high
    s: comma seperated list of sizes
    u: underwater
walkpath neighbors and neighbors are | seperated indecies
transportlinks is | seperated transport links in the form
    name/type/faction/classrestriction/destinations
where destination is a , seperated list of destinaion indecies in form zone[transportlink]
NOTE: This list will likely have empty spots in it, and ipairs cannot be used to iterate over it.
]]--
local v1, v2, v3 = strsplit( ".", GetBuildInfo() )
local version = tonumber( v1 ) * 10000 + tonumber( v2 ) * 100 + tonumber( v3 )

if( version >= 40001 ) then
    Broker_RecZone.vars.packedZones = {
        [1] = "Blade's Edge Arena;0;0;3;9;128;m;;;",
        [2] = "Dalaran;0;0;4;2;255;m;180|173;;Dalaran/1/3///167[1],179[2],180[1],179[3],167[5],180[2],174[2],207[1],179[1],176[2],183[1],183[2],195[1]|Stormwind City Portal/4/1///14|Ironforge Portal/4/1///7|Darnassus Portal/4/1///4|The Exodar Portal/4/1///15|Shattrath City Portal/4/1///12|Orgrimmar Portal/4/2///10|Thunder Bluff Portal/4/2///22|Undercity Portal/4/2///24|Silvermoon City Portal/4/2///13|Shattrath City Portal/4/2///12|Caverns of Time Portal/4/3///135",
        [3] = "Dalaran Sewers;0;0;4;9;128;m;;;",
        [4] = "Darnassus;0;0;1;2;1;f|m;33;;Blasted Lands Portal/4/1///89",
        [5] = "Deeprun Tram;0;0;2;2;1;;14|7;;",
        [7] = "Ironforge;0;0;2;2;1;f|m;5|27;;Ironforge/1/1///14[1],96[1],82[1],68[1],56[1],58[1],40[1],103[1],87[1],137[1]|Blasted Lands Portal/4/1///89",
        [8] = "Moonglade;0;0;1;2;128;f|m;105|93|188;38;Nighthaven/1/3/Druid//33[1],22[1]|Moonglade/1/1///105[1]|Moonglade/1/2///93[2],105[1]",
        [9] = "Nagrand Arena;0;0;3;9;128;m;;;",
        [10] = "Orgrimmar;0;0;1;2;2;f|m;28|47|36;;Orgrimmar/1/2///22[1],53[3],52[2],81[1],93[2],36[2],105[1],41[1]|Blasted Lands Portal/4/1///89",
        [11] = "Ruins of Lordaeron;0;0;2;9;128;m;;;",
        [12] = "Shattrath City;0;0;3;2;255;f|m;128;;Shattrath City/1/1///118[2],124[2],128[1],133[1]|Shattrath City/1/2///118[8],124[3],128[2],133[2]|Stormwind City Portal/4/1///14|Ironforge Portal/4/1///7|Darnassus Portal/4/1///4|The Exodar Portal/4/1///15|Orgrimmar Portal/4/2///10|Thunder Bluff Portal/4/2///22|Undercity Portal/4/2///24|Silvermoon City Portal/4/2///13|Zephyr/4/3///135|Isle of Quel'Danas Portal/4/3///137",
        [13] = "Silvermoon City;0;0;2;2;2;f|m;30;;Silvermoon City/1/2///39[1],137[1]|Orb of Translocation/4/2///24[1]|Blasted Lands Portal/4/1///89",
        [14] = "Stormwind City;0;0;2;2;1;f|m;5|29|57;;Stormwind City/1/1///7[1],95[1],48[1],44[1],55[1],89[1],87[1],62[1],66[1]|The Bravery/2/1//14/33[1]|The Kraken/2/1//14/147[1]|Blasted Lands Portal/4/1///89|Elune's Blessing/2/1//14/15",
        [15] = "The Exodar;0;0;1;2;1;f|m;26;;The Exodar/1/1///37[1]|Elune's Blessing/2/1//15/14|Blasted Lands Portal/4/1///89",
        [16] = "The Forbidding Sea;0;0;2;3;128;f|m;;;",
        [17] = "The Frozen Sea;0;0;4;3;128;f|m;;;",
        [18] = "The Great Sea;0;0;128;3;128;f|m;;;",
        [19] = "The North Sea;0;0;2;3;128;f|m;;;",
        [20] = "The Ring of Valor;0;0;1;9;128;m;;;",
        [21] = "The Veiled Sea;0;0;1;3;128;f|m;;;",
        [22] = "Thunder Bluff;0;0;1;2;2;f|m;32;;Thunder Bluff/1/2///75[3],80[3],63[1],10[1],52[2],69[2],36[2],81[1],41[1]|Blasted Lands Portal/4/1///89",
        [23] = "Twisting Nether;0;0;3;3;128;f|m;;;",
        [24] = "Undercity;0;0;2;2;2;f|m;34;;Undercity/1/2///42[1],56[2],68[2],82[2],74[1],103[1],34[4]|Orb of Translocation/4/2///13[1]|Blasted Lands Portal/4/1///89",
        [25] = "Kezan;1;7;5;1;2;m;;;",
        [26] = "Azuremyst Isle;1;12;1;1;1;f|m;37|15;;",
        [27] = "Dun Morogh;1;12;2;1;1;f|m;7|40|61;74|95|58|87;",
        [28] = "Durotar;1;12;1;1;2;f|m;10|36|41;53;The Iron Eagle/3/2//28/62[2]|The Thundercaller/3/2//28/34|The Mighty Wind/3/2//28/147[6]|The Zephyr/3/2//28/22",
        [29] = "Elwynn Forest;1;12;2;1;1;f|m;14|44|48|55;95|102;",
        [30] = "Eversong Woods;1;12;2;1;2;f|m;39|13;;",
        [31] = "Gilneas;1;12;2;1;1;f|m;42;;",
        [32] = "Mulgore;1;12;1;1;2;f|m;22|43;52|69|80;",
        [33] = "Teldrassil;1;12;1;1;1;f|m;4;;Rut'theran Village/1/1///|The Bravery/2/1//33[1]/14",
        [34] = "Tirisfal Glades;1;12;2;1;2;f|m;24|42|96|65;67;The Purple Princess/3/2//34/62[2]|The Thundercaller/3/2//34/28|The Cloudkisser/3/2//34/148[8]|The Bulwark/1/2///24[1],96[2]",
        [35] = "The Lost Isles;7;12;5;1;2;m;;;",
        [36] = "Azshara;10;20;1;1;2;f|m;28|53|10;105;Talrendis Point/1/1///75[1],93[1],105[1],41[2]|Valormok/1/2///10[1],22[1],53[3],93[2],105[1],41[1]",
        [37] = "Bloodmyst Isle;10;20;1;1;1;f|m;26;;Blood Watch/1/1///15[1]",
        [38] = "Darkshore;10;20;1;1;1;f|m;53;8|93;",
        [39] = "Ghostlands;10;20;2;1;2;f|m;30|103|164;;Tranquillien/1/2///13[1],103[1],39[2]|Hatchet Hills/1/3///103[1],39[1],137[1]",
        [40] = "Loch Modan;10;20;2;1;1;f|m;27|58|74;;Thelsamar/1/1///7[1],58[1],68[1]",
        [41] = "Northern Barrens;10;20;1;1;2;f|m;28|53|51|46;52;The Crossroads/1/2///93[2],75[3],80[3],63[1],10[1],53[3],52[2],22[1],36[2],53[4],81[1],41[2]|Ratchet/1/2///53[1],36[1],75[1],10[1],41[1],81[1]|The Maiden's Fancy/2/3//41[2]/66[1]",
        [42] = "Silverpine Forest;10;20;2;1;2;f|m;34|56|67|49|31;;The Sepulcher/1/2///24[1],56[2]",
        [43] = "Southern Barrens;10;20;1;1;2;f|m;32|52|63|75|60|72|46;80;",
        [44] = "Westfall;10;20;2;1;1;f|m;29|55|50;62;Sentinel Hill/1/1///14[1],48[1],55[1],62[1],66[1]",
        [46] = "Warsong Gulch|WSG;10;-1;1;8;128;s10|r10:19,20:29,30:39,40:49,50:59,60:69,70:79,80:84,85:85|m;53|41;;",
        [47] = "Ragefire Chasm|RFC;15;25;1;6;128;b4;10;;",
        [48] = "Redridge Mountains;15;25;2;1;128;f|m;29|95;77|102;Lakeshire/1/1///14[1],44[1],55[1],95[1]",
        [49] = "Shadowfang Keep|SFK;15;25;2;6;128;b8|h85,87|d2;42;;",
        [50] = "The Deadmines|VC|DMVC|DM;15;25;2;6;128;b8|h85,87;44;;",
        [51] = "Wailing Caverns|WC;15;25;1;6;128;b8;43;;",
        [52] = "Stonetalon Mountains;15;27;1;1;128;f|m;53|69|43;32;Stonetalon Peak/1/1///53[1],69[1]|Sun Rock Retreat/1/2///22[1],69[2],41[1]",
        [53] = "Ashenvale;15;30;1;1;128;f|m;38|52|36|93|54|46|41;28|105;Astranaar/1/1///52[1],53[2],36[1],93[3]|Forest Song/1/1///53[1],36[1],93[3]|Splintertree Post/1/2///10[1],53[4],36[2],41[1]|Zoram'gar Outpost/1/2///53[3],22[1],52[2],41[1]",
        [54] = "Blackfathom Deeps|BFD;19;29;1;6;128;b8;53;;",
        [55] = "Duskwood;20;30;2;1;128;f|m;29|44|102|62;;Darkshire/1/1///14[1],44[1],48[1],89[1],62[1],66[1]",
        [56] = "Hillsbrad Foothills;20;30;2;1;128;f|m;42|67|68;82;Southshore/1/1///7[1],58[1],68[1],82[1],96[1]|Tarren Mill/1/2///24[1],42[1],68[2],82[2]",
        [57] = "The Stockade|Stocks;20;30;2;6;128;b5;14;;",
        [58] = "Wetlands;20;30;2;1;128;f|m;40|68|219;27;Menethil Harbor/1/1///7[1],40[1],68[1],56[1]|The Lady Mehley/2/1//58[1]/75[1]|Northspear/2/1//58[1]/148[2]",
        [59] = "Arathi Basin|AB;20;-1;2;8;128;s15|r20:29,30:39,40:49,50:59,60:69,70:79,80:84,85:85|m;68;;",
        [60] = "Razorfen Kraul|RFK;22;32;1;6;128;b6;43;;",
        [61] = "Gnomeregan|GR|Gnome|Gnomer;23;33;2;6;128;b7;27;;",
        [62] = "Northern Stranglethorn;25;30;2;1;128;f|m;55|66;44|89|102;Rebel Camp/1/1///14[1],44[1],55[1],66[1]|Grom'gol Base Camp/1/2///77[1],74[1],66[1]|The Purple Princess/3/2//62[2]/34|The Iron Eagle/3/2//62[2]/28",
        [63] = "Thousand Needles;25;35;1;1;128;f|m;80|81|43;94|104|75;Freewind Post/1/2///22[1],80[3],81[1],41[1]",
        [64] = "Scarlet Monastery (Graveyard)|SMG|SM-G;27;37;2;6;128;b2|d8;65;;",
        [65] = "Scarlet Monastery|SM;27;45;2;5;128;;34|64|70|73|76;;",
        [66] = "The Cape of Stranglethorn;30;35;2;1;128;f|m;62;;Booty Bay/1/1///14[1],44[1],55[1],62[1]|The Maiden's Fancy/2/3//66[1]/41[2]|Booty Bay/1/2///62[2],77[1],74[1]",
        [67] = "Alterac Mountains;30;40;2;1;128;f|m;42|56|82|96|98;34;",
        [68] = "Arathi Highlands;30;40;2;1;128;f|m;58|56|59;82;Refuge Pointe/1/1///7[1],40[1],58[1],56[1],82[1]|Hammerfall/1/2///24[1],56[2],74[1],82[2]",
        [69] = "Desolace;30;40;1;1;128;f|m;52|80|85;32;Nijel's Point/1/1///52[1],75[1],80[1]|Shadowprey Village/1/2///22[1],52[2],80[3]",
        [70] = "Scarlet Monastery (Library)|SML|SM-L;30;40;2;6;128;b2;65;;",
        [72] = "Razorfen Downs|RFD;32;42;1;6;128;b5;43;;",
        [73] = "Scarlet Monastery (Armory)|SMA|SM-A;32;42;2;6;128;b1;65;;",
        [74] = "Badlands;35;45;2;1;128;m;40|87|78;95|27;Kargath/1/2///24[1],68[2],77[1],87[1],95[2],62[2],66[1]",
        [75] = "Dustwallow Marsh;35;45;1;1;128;f|m;199|43;63;Theramore Isle/1/1///69[1],80[2],81[1],36[1],75[4],41[2]|The Lady Mehley/2/1//75[1]/58[1]|Brackenwall Village/1/2///10[1],22[1],81[1],75[4],41[1]|Mudsprocket/1/3///63[1],75[3],80[2],75[1]",
        [76] = "Scarlet Monastery (Cathedral)|SMC|SM-C;35;45;2;6;128;b3;65;;",
        [77] = "Swamp of Sorrows;35;45;2;1;128;f|m;89|102|88;48;Stonard/1/2///24[1],74[1],95[2],62[2],66[1]",
        [78] = "Uldaman;35;45;2;6;128;b8;74;;",
        [79] = "Maraudon (Purple Crystals)|Mara;39;49;1;6;128;b3;85;;",
        [80] = "Feralas;40;50;1;1;128;f|m;63|69|100;32|104|94|43;Feathermoon Stronghold/1/1///69[1],80[2],104[1]|Thalanaar/1/1///75[1],80[1],81[1]|Camp Mojache/1/2///22[1],63[1],69[2],81[1],104[1],41[1]",
        [81] = "Tanaris;40;50;1;1;128;f|m;63|94|84|135|217;;Gadgetzan/1/1///75[1],80[2],94[1],104[1],75[4],41[2]|Gadgetzan/1/2///10[1],22[1],75[3],80[3],94[1],104[1],75[4],41[1],41[2]",
        [82] = "The Hinterlands;40;50;2;1;128;f|m;67|96;56|68|103;Aerie Peak/1/1///7[1],56[1],68[1],96[1],103[1]|Revantusk Village/1/2///24[1],56[2],68[2],103[1]",
        [83] = "Maraudon (Orange Crystals)|Mara;41;51;1;6;128;b4;85;;",
        [84] = "Zul'Farrak|ZF;41;51;1;6;128;b8|m;81;;",
        [85] = "Maraudon;41;53;1;5;128;;69|83|79|86;;",
        [86] = "Maraudon (Pristine Waters)|Mara;41;53;1;6;128;b4;85;;",
        [87] = "Searing Gorge;43;50;2;1;128;f|m;74|92;27|95;Thorium Point/1/3///7[1],14[1],40[1],95[1],96[1],74[1],95[2]",
        [88] = "The Temple of Atal'Hakkar|ST|Temple|!Sunken Temple;45;55;2;6;128;b10;77;;",
        [89] = "Blasted Lands;47;55;2;1;128;f|m;77;102|62;Nethergarde Keep/1/1///14[1],55[1],95[1]|The Dark Portal/4/3///118",
        [90] = "Blackrock Depths (Lower City)|BRD;47;57;2;6;128;b1;91;;",
        [91] = "Blackrock Depths;47;61;2;5;128;;92|90;;",
        [92] = "Blackrock Mountain;47;62;2;5;128;;87|95|91|107|225|224;;",
        [93] = "Felwood;48;55;1;1;128;f|m;53|105|8;38;Talonbranch Glade/1/1///36[1],8[2],105[1]|Bloodvenom Post/1/2///10[1],36[2],8[2],105[1],41[1]|Emerald Sanctuary/1/3///93[1],93[2]",
        [94] = "Un'Goro Crater;48;55;1;1;128;f|m;81|104;63|80|217;Marshal's Refuge/1/3///81[1],104[1]",
        [95] = "Burning Steppes;50;60;2;1;128;f|m;48|92;74|87|29;Morgan's Vigil/1/1///14[1],48[1],87[1],89[1]|Flame Crest/1/2///77[1],74[1],87[1]",
        [96] = "Western Plaguelands;50;60;2;1;128;f|m;34|67|82|103|110;;Chillwind Camp/1/1///7[1],56[1],82[1],103[1]|Thondroril River/1/3///103[1],7[1],96[1],82[1],24[1],82[2],34[4]",
        [97] = "Blackrock Depths (Upper City)|BRD;51;61;2;6;128;b19|d6;91;;",
        [98] = "Alterac Valley|AV;51;-1;2;8;128;s40|r51:60,61:70,71:79,80:84,85:85|m;67;;",
        [99] = "Dire Maul (East)|DME|DM-E;53;63;1;6;128;b5;100;;",
        [100] = "Dire Maul|DM;53;65;1;5;128;;80|99|109|108;;",
        [101] = "Plaguelands: The Scarlet Enclave;55;58;2;1;128;m;;;",
        [102] = "Deadwind Pass;55;60;2;1;128;f|m;55|77|159;48|89|29|62;",
        [103] = "Eastern Plaguelands;55;60;2;1;128;f|m;96|111|39;82;Light's Hope Chapel/1/3///7[1],82[1],96[1],24[1],82[2],39[1],39[2],103[2]|Acherus: The Ebon Hold/1/3/Death Knight//103[1],96[1],82[1],39[1]",
        [104] = "Silithus;55;60;1;1;128;f|m;94|120|123;63|80|217;Cenarion Hold/1/3///80[1],80[3],81[1],94[1]",
        [105] = "Winterspring;55;60;1;1;128;f|m;8|93|188;36|53;Everlook/1/1///93[1],8[2],36[1]|Everlook/1/2///10[1],93[2],8[2]",
        [106] = "Blackrock Spire|BRS;55;65;2;5;128;;92|107;;",
        [107] = "Blackrock Spire|LBRS|!Lower Blackrock Spire;55;65;2;6;128;b9;106|114;;",
        [108] = "Dire Maul (North)|DMN|DM-N;55;65;1;6;128;b7;100;;",
        [109] = "Dire Maul (West)|DMW|DM-W;55;65;1;6;128;b5;100;;",
        [110] = "Scholomance|Scholo;55;65;2;6;128;b13;96;;",
        [111] = "Stratholme;55;65;2;5;128;;103|112|113;;",
        [112] = "Stratholme (Main Gate)|Strat;55;65;2;6;128;b10;111;;",
        [113] = "Stratholme (Service Entrance)|Strat;55;65;2;6;128;b7;111;;",
        [114] = "Blackrock Spire|UBRS|!Upper Blackrock Spire;56;63;2;7;128;p-1|s10;107|121;;",
        [116] = "Hellfire Ramparts|HFR|Ramp|Ramps|Ramparts;57;67;3;6;128;b3|h70,75;117;;",
        [117] = "Hellfire Citadel;57;75;3;5;128;;118|116|119|144|160;;",
        [118] = "Hellfire Peninsula;58;63;3;1;128;f|m;124|128|117;;The Dark Portal/4/3///89|Honor Hold/1/1///118[3],118[4],128[1],12[1],118[5]|Shatter Point/1/1///118[2]|Temple of Telhamat/1/1///118[2],124[2]|The Stair of Destiny/1/1///118[2],118[3],118[4],12[1]|Stormwind City Portal/4/1///14|Thrallmar/1/2///118[8],118[9],128[2],12[1],118[5]|Falcon Watch/1/2///118[7],124[3],124[4],133[2]|Spinebreaker Post/1/2///118[7]|The Stair of Destiny/1/2///118[7],118[8],12[1]|Orgrimmar Portal/4/2///10",
        [119] = "The Blood Furnace|BF;59;68;3;6;128;b3|h70,75;117;;",
        [120] = "Ahn'Qiraj|AQ20;60;63;1;7;128;p4|s20|m;104;;",
        [121] = "Blackwing Lair|BWL;60;63;2;7;128;p5|s40;114;;",
        [122] = "Molten Core|MC;60;63;2;7;128;p3|s40;91;;",
        [123] = "Temple of Ahn'Qiraj|AQ40;60;63;2;7;128;p6|s40|m;104;;",
        [124] = "Zangarmarsh;60;64;3;1;128;f|m;118|128|133|136|130;;Orebor Harborage/1/1///136[1],124[2]|Telredor/1/1///124[1],136[1],133[1],118[4],136[2],12[1]|Swamprat Post/1/2///118[8],136[4],136[3],124[4],12[1]|Zabra'jin/1/2///118[8],133[2],124[3],136[3],12[1]",
        [125] = "The Slave Pens|SP;60;69;3;6;128;b3|h70,75|d5;130;;",
        [126] = "The Underbog|UB|Bog;61;70;3;6;128;b5|h70,75;130;;",
        [127] = "Eye of the Storm|EotS|Eye;61;-1;3;8;128;s15|r61:69,70:79,80:84,85:85|m;;;",
        [128] = "Terokkar Forest;62;65;3;1;128;f|m;118|124|133|140|131|12;;Allerian Stronghold/1/1///118[2],133[1],140[1],12[1]|Stonebreaker Hold/1/2///118[7],140[2],12[1]",
        [129] = "Mana-Tombs|MT|Tombs;62;70;3;6;128;b3|h70,75;131;;",
        [130] = "Coilfang Reservoir;62;75;3;5;128;;124|125|126|145|161;;",
        [131] = "Ring of Observance|!Auchindoun;62;75;3;5;128;;128|132|141|138|129;;",
        [132] = "Auchenai Crypts|AC|Crypts;63;72;3;6;128;b2|h70,75;131;;",
        [133] = "Nagrand;64;67;3;1;128;f|m;124|128;;Telaar/1/1///124[2],128[1],12[1]|Garadar/1/2///118[8],124[4],12[1]",
        [134] = "Old Hillsbrad Foothills|CoT:Durnholde|Thrall|CoT 1|Old Hillsbrad|Durn|OH|DH|!The Escape from Durnholde Keep;64;73;1;6;128;b3|h70,75|m;135;;",
        [135] = "Caverns of Time;64;80;1;5;128;;81|134|146|158|184;;",
        [136] = "Blade's Edge Mountains;65;68;3;1;128;f|m;124|139|157;;Sylvanaar/1/1///136[2],124[1],124[2],139[2],139[1],136[5]|Toshley's Station/1/1///136[1],139[1]|Thunderlord Stronghold/1/2///136[4],124[3],124[4],136[5],139[1],139[2]|Mok'Nathal Village/1/2///136[3],139[1]|Evergrove/1/3///136[1],136[2],136[3],139[1]",
        [137] = "Isle of Quel'Danas;65;70;2;1;128;f|m;149|162;;Sun's Reach/1/3///13[1],7[1],39[2],103[1]",
        [138] = "Sethekk Halls|Seth|Sethekk;65;73;3;6;128;b2|h70,75,3;131;;",
        [139] = "Netherstorm;67;70;3;1;128;f|m;136|150;;Area 52/1/3///136[1],136[2],136[3],136[4],139[2],139[3],136[5]|The Stormspire/1/3///136[1],136[3],139[1],139[3]|Cosmowrench/1/3///139[1],139[2]",
        [140] = "Shadowmoon Valley;67;70;3;1;128;f|m;128|156;;Wildhammer Stronghold/1/1///128[1],140[3],140[4]|Shadowmoon Village/1/2///128[2],140[3],140[4]|Altar of Sha'tar/1/3///140[1],140[2]|Sanctum of the Stars/1/3///140[1],140[2]",
        [141] = "Shadow Labyrinth|SL|Lab|Slabs|Shadow Labs;67;75;3;6;128;b4|h70,75;131;;",
        [142] = "The Botanica|Bot;67;75;3;6;128;b5|h70,75;150;;",
        [143] = "The Mechanar|Mech;67;75;3;6;128;b4|h70,75;150;;",
        [144] = "The Shattered Halls|SH;67;75;3;6;128;b3|h70,75;117;;",
        [145] = "The Steamvault|SV|Vaults;67;75;3;6;128;b3|h70,75;130;;",
        [146] = "The Black Morass|CoT:Dark Portal|CoT:DP|BM|CoT 2|!Opening the Dark Portal;68;70;1;6;128;b3|h70,75|m;135;;",
        [147] = "Borean Tundra;68;72;4;1;128;f|m;167|176|155;;Valiance Keep/1/1///147[3],167[2],147[8],155[1],147[9]|The Kraken/2/1//147[1]/14|Fizzcrank Airstrip/1/1///167[2],147[1],147[8],176[1],176[2],147[9]|Bor'gorok Outpost/1/2///147[6],147[8],176[1],176[2]|Taunka'le Village/1/2///167[4],147[4],147[6],147[8],147[9]|Warsong Hold/1/2///167[4],147[4],147[5],147[8],155[1],147[9]|The Mighty Wind/3/2//147[6]/28|Amber Ledge/1/3///147[3],147[1],147[4],147[5],147[6],155[1]|Unu'pe/1/3///147[3],147[1],147[5],147[6]|Walker of Waves/2/3//147[9]/167[7]",
        [148] = "Howling Fjord;68;72;4;1;128;f|m;172|153;;Fort Wildervar/1/1///172[1],148[1],148[4],148[10]|Valgarde/1/1///148[1],148[4],148[10]|Northspear/2/1//148[2]/58[1]|Westguard Keep/1/1///172[1],148[1],167[3],148[10]|Apothecary Camp/1/2///148[6],172[3],148[7],148[10]|Camp Winterhoof/1/2///148[5],172[4],148[7],148[8]|New Agamand/1/2///148[5],148[6],148[8],167[6],148[10]|Vengeance Landing/1/2///172[4],148[6],148[7]|The Cloudkisser/3/2//148[8]/34|Kamagua/1/3///148[2],148[4],148[5],148[7]|Green Island/2/3//148[10]/167[7]",
        [149] = "Magisters' Terrace|MgT|MsT|MrT|QD5|MT;68;75;2;6;128;b3|h70,75;137;;",
        [150] = "Tempest Keep;68;75;3;5;128;;139|143|142|151|163;;",
        [151] = "The Arcatraz|AZ|Arca;68;75;3;6;128;b5|h70,75;150;;",
        [152] = "Utgarde Keep|UK;68;80;4;6;128;b3|h80,83;153;;",
        [153] = "Utgarde Keep;68;83;4;5;128;;148|152|186;;",
        [154] = "The Nexus|Nex|Nexus;69;80;4;6;128;b4|h80,83,5;155;;",
        [155] = "Coldarra|!The Nexus;69;83;4;5;128;;147|154|185|200;;Transitus Shield/1/3///147[1],147[6],147[8]",
        [156] = "Black Temple|BT;70;73;3;7;128;p8|s25;140;;",
        [157] = "Gruul's Lair|GL;70;73;3;7;128;p2|s25;136;;",
        [158] = "Hyjal Summit|HY|MH|!Battle for Mount Hyjal;70;73;1;7;128;p7|s25|m;135;;",
        [159] = "Karazhan|KZ|Kara;70;73;2;7;128;p1|s10;102;;",
        [160] = "Magtheridon's Lair|ML|Mag;70;73;3;7;128;p3|s25;117;;",
        [161] = "Serpentshrine Cavern|SSC;70;73;3;7;128;p5|s25;130;;",
        [162] = "Sunwell Plateau|SWP|QD25;70;73;2;7;128;p9|s25|m;137;;",
        [163] = "The Eye|Eye|TE;70;73;3;7;128;p6|s25;150;;",
        [164] = "Zul'Aman|ZA;70;73;2;7;128;p4|s10|m;39;;",
        [165] = "Azjol-Nerub|AN|Nerub;70;80;4;6;128;b3|h80,83;166;;",
        [166] = "The Pit of Narjun;70;83;4;5;128;;167|165|168;;",
        [167] = "Dragonblight;71;74;4;1;128;f|m;147|174|172|180|166|207|198;;Fordragon Hold/1/1///167[2],167[3],2[1],174[2],207[1]|Stars' Rest/1/1///147[3],167[1],147[1],167[3],167[7],147[9],207[1]|Wintergarde Keep/1/1///172[1],167[1],167[2],148[4],174[2],174[3],167[7],207[1]|Agmar's Hammer/1/2///167[5],147[5],167[6],147[6],167[7],207[1]|Kor'kron Vanguard/1/2///167[4],167[6],2[1],207[1]|Venomspite/1/2///167[4],172[3],167[5],148[7],174[3],167[7]|Moa'ki Harbor/1/3///167[2],167[3],167[4],167[6],2[1],207[1]|Walker of Waves/2/3//167[7]/147[9]|Green Island/2/3//167[7]/148[10]",
        [168] = "Ahn'kahet: The Old Kingdom|AK|Kahet|Old Kingdom;71;80;4;6;128;b4|h80,83,5;166;;",
        [169] = "Isle of Conquest|IoC;71;-1;4;8;128;s40|r71:79,80:80|m;;;",
        [170] = "Strand of the Ancients|SotA;71;-1;4;8;128;s15|r71:79,80:84,85:85|m;;;",
        [171] = "Drak'Tharon Keep|DTK|DK;72;80;4;6;128;b4|h80,83;172;;",
        [172] = "Grizzly Hills;73;75;4;1;128;f|m;148|174|167|171;;Amberpine Lodge/1/1///172[2],148[4],167[3]|Westfall Brigade Encampment/1/1///172[1],148[1],174[1],174[4]|Conquest Hold/1/2///172[4],148[5],167[6]|Camp Oneqwah/1/2///172[3],148[6],174[1],174[4]",
        [173] = "The Violet Hold|VH;73;80;4;6;128;b3|h80,83;2;;",
        [174] = "Zul'Drak;74;77;4;1;128;f|m;172|180|167|175;;Argent Stand/1/3///172[2],172[4],174[2],179[1],174[3],174[4]|Ebon Watch/1/3///179[2],180[1],167[3],179[3],180[2],167[6],174[1],2[1],179[1],174[3]|Light's Breach/1/3///172[1],167[3],172[4],172[3],167[6],174[1],174[2],179[1]|Zim'Torga/1/3///172[2],172[4],179[4],174[1],179[1],174[5]|Gundrak/1/3///174[4]",
        [175] = "Gundrak|GD|Gun;74;80;4;6;128;b4|h80,83,5;174;;",
        [176] = "Sholazar Basin;75;78;4;1;128;f|m;147;;Nesingwary Base Camp/1/3///176[2],183[3],147[3]|River's Heart/1/3///176[1],183[3],147[3],147[4]",
        [177] = "Halls of Stone|HoS;75;80;4;6;128;b4|h80,83;178;;",
        [178] = "Ulduar;75;83;4;5;128;;179|177|181|204;;Ulduar/1/3///179[2],179[4],179[3],179[6],179[5],174[4]",
        [179] = "The Storm Peaks;76;80;4;1;128;f|m;180|178;;K3/1/3///179[5],179[3],179[2],174[2],2[1],180[1],180[2]|Frosthold/1/1///179[6],179[1],178[1],183[1]|Grom'arsh Crash-Site/1/2///179[4],179[6],179[1],178[1],183[1]|Camp Tunka'lo/1/2///179[3],179[1],178[1],174[4]|Dun Niffelem/1/3///179[1],178[1],174[4]|Bouldercrag's Refuge/1/3///179[2],179[3],178[1],195[1]",
        [180] = "Crystalsong Forest;77;80;4;1;128;f|m;2|174|167|183|179;;Windrunner's Overlook/1/1///167[1],179[2],167[3],2[1],174[2],179[1]|Sunreaver's Command/1/2///179[3],167[5],2[1],174[2],179[1]",
        [181] = "Halls of Lightning|HoL;77;80;4;6;128;b4|h80,83;178;;",
        [182] = "Hrothgar's Landing;77;80;4;1;128;f|m;183;;",
        [183] = "Icecrown;77;80;4;1;128;f|m;180|195|182|196;;The Argent Vanguard/1/3///183[2],2[1],179[2],179[3],183[4]|Crusaders' Pinnacle/1/3///183[1],2[1],183[3],183[4],195[1]|Death's Rise/1/3///183[2],176[1],176[2],183[4]|The Shadow Vault/1/3///183[1],179[6],183[2],183[3],195[1]",
        [184] = "The Culling of Stratholme|CoS|CoT:CoS|CoT 3|Old Strat|CoT:Strat|Stratholme Past;77;80;1;6;128;b4|h80,83,5|m;135;;",
        [185] = "The Oculus|OCC;77;80;4;6;128;b4|h80,83|m;155;;",
        [186] = "Utgarde Pinnacle|UP;77;80;4;6;128;b4|h80,83;153;;",
        [187] = "Wintergrasp|WG;77;80;4;4;4;f|m;206;;",
        [188] = "Mount Hyjal;78;82;1;1;128;f|m;8|105|226;;",
        [189] = "Halls of Reflection|HoR;80;80;4;6;128;b3|h80,83;196;;",
        [190] = "Pit of Saron|PoS;80;80;4;6;128;b3|h80,83;196;;",
        [191] = "The Forge of Souls|FoS;80;80;4;6;128;b2|h80,83;196;;",
        [192] = "Trial of the Champion;80;80;4;6;128;b3|h80,83|m;195;;",
        [193] = "Vashj'ir;80;82;5;1;128;m|u;210;;",
        [194] = "Vortex Pinnacle|VP;80;82;5;6;128;h85,87|f|m;208;;",
        [195] = "Argent Tournament Grounds;80;83;4;5;128;;183|192|203;;Argent Tournament Grounds/1/1///179[6],183[2],2[1],183[4]|Argent Tournament Grounds/1/2///179[6],183[2],2[1],183[4]",
        [196] = "Icecrown Citadel;80;83;4;5;128;;183|197|191|190|189;;",
        [197] = "Icecrown Citadel|ICC|IC;80;83;4;7;128;p8|s10,25|h80,83;196;;",
        [198] = "Naxxramas|Naxx;80;83;4;7;128;p1|s10,25;167;;",
        [199] = "Onyxia's Lair|Ony|Onx|Onyxia;80;83;1;7;128;p5|s10,25;75;;",
        [200] = "The Eye of Eternity|EoE|Eye;80;83;4;7;128;p3|s10,25;155;;",
        [201] = "The Obsidian Sanctum|OS|TOS;80;83;4;7;128;p2|s10,25;207;;",
        [202] = "The Ruby Sanctum|RS|TRS;80;83;4;7;128;p7|s10,25;207;;",
        [203] = "Trial of the Crusader;80;83;4;7;128;p6|s10,25|h80,83|m;195;;",
        [204] = "Ulduar|Uld;80;83;4;7;128;p4|s10,25|m;178;;",
        [205] = "Vault of Archavon|VoA;80;83;4;7;128;p0|s10,25;206;;",
        [206] = "Wintergrasp Fortress;80;83;4;5;128;;187|205;;",
        [207] = "Wyrmrest Temple;80;83;4;5;128;;167|201|202;;Wyrmrest Temple/1/3///167[1],167[2],167[3],167[4],167[5],167[6],2[1],174[2],167[7]",
        [208] = "Skywall;80;85;5;5;128;;217|194|229;;",
        [209] = "Abyssal Maw|AM;81;83;5;6;128;h85,87;210;;",
        [210] = "Abyssal Maw;81;85;2;5;128;;193|209|216;;",
        [211] = "Battle for Gilneas City|BfGC;81;-1;2;8;128;s40|r81:85|m;;;",
        [212] = "Twin Peaks|TP;81;-1;2;8;128;s10|r81:85|m;;;",
        [213] = "Deepholm;82;84;5;1;128;f|m;214|215;;",
        [214] = "Maelstrom;82;84;5;1;255;f|m;213;;",
        [215] = "Stonecore|SC;82;84;5;6;128;h85,87;213;;",
        [216] = "Throne of the Tides|TotT;82;84;5;6;128;h85,87;210;;",
        [217] = "Uldum;83;84;1;1;128;f|m;81|228|220|208;94|104;",
        [218] = "Tol Barad|TB;84;85;2;4;4;f|m;222;;",
        [219] = "Twilight Highlands;84;85;2;1;128;f|m;58|221;;",
        [220] = "Lost City of Tol'vir|LCoT|Tol'vir;84;87;1;6;128;h85,87;217;;",
        [221] = "Grim Batol;85;85;2;5;128;;219|227|223;;",
        [222] = "Baradin Hold|BH;85;87;2;7;128;p-1|s10,25;218;;",
        [223] = "Bastion of Twilight|BoT|GBR;85;87;2;7;128;p1|s10,25;221;;",
        [224] = "Blackrock Caverns|BRC;85;87;2;6;128;h85,87;92;;",
        [225] = "Blackwing Descent|BWD;85;87;2;7;128;p-1|s10,25;92;;",
        [226] = "Firelands|FL;85;87;5;7;128;p-1|s10,25|m;188;;",
        [227] = "Grim Batol|GB;85;87;2;6;128;h85,87;221;;",
        [228] = "Halls of Origination|HoO;85;87;1;6;128;h85,87;217;;",
        [229] = "Throne of the Four Winds|TotFW|Tot4W|SWR;85;87;5;7;128;p-1|s10,25|m;208;;",
    };
else
    Broker_RecZone.vars.packedZones = {
        [1] = "Blade's Edge Arena;0;0;3;9;128;m;;;",
        [2] = "Dalaran;0;0;4;2;255;m;180|173;;Dalaran/1/3///167[1],179[2],180[1],179[3],167[5],180[2],174[2],207[1],179[1],176[2],183[1],183[2],195[1]|Stormwind City Portal/4/1///14|Ironforge Portal/4/1///7|Darnassus Portal/4/1///4|The Exodar Portal/4/1///15|Shattrath City Portal/4/1///12|Orgrimmar Portal/4/2///10|Thunder Bluff Portal/4/2///22|Undercity Portal/4/2///24|Silvermoon City Portal/4/2///13|Shattrath City Portal/4/2///12|Caverns of Time Portal/4/3///135",
        [3] = "Dalaran Sewers;0;0;4;9;128;m;;;",
        [4] = "Darnassus;0;0;1;2;1;m;33;;Blasted Lands Portal/4/1///89",
        [5] = "Deeprun Tram;0;0;2;2;1;;14|7;;",
        [6] = "Hyjal;0;0;1;3;128;m;;;",
        [7] = "Ironforge;0;0;2;2;1;m;5|27;;Ironforge/1/1///14[1],96[1],82[1],68[1],56[1],58[1],40[1],103[1],87[1],137[1]|Blasted Lands Portal/4/1///89",
        [8] = "Moonglade;0;0;1;2;128;m;105|93;38;Nighthaven/1/3/Druid//33[1],22[1]|Moonglade/1/1///38[1],105[1]|Moonglade/1/2///93[2],105[1]",
        [9] = "Nagrand Arena;0;0;3;9;128;m;;;",
        [10] = "Orgrimmar;0;0;1;2;2;m;28|47;36;Orgrimmar/1/2///22[1],45[1],45[2],53[3],52[2],81[1],93[2],36[2],105[1]|Blasted Lands Portal/4/1///89",
        [11] = "Ruins of Lordaeron;0;0;2;9;128;m;;;",
        [12] = "Shattrath City;0;0;3;2;255;f|m;128;;Shattrath City/1/1///118[2],124[2],128[1],133[1]|Shattrath City/1/2///118[8],124[3],128[2],133[2]|Stormwind City Portal/4/1///14|Ironforge Portal/4/1///7|Darnassus Portal/4/1///4|The Exodar Portal/4/1///15|Orgrimmar Portal/4/2///10|Thunder Bluff Portal/4/2///22|Undercity Portal/4/2///24|Silvermoon City Portal/4/2///13|Zephyr/4/3///135|Isle of Quel'Danas Portal/4/3///137",
        [13] = "Silvermoon City;0;0;2;2;2;m;30;;Silvermoon City/1/2///39[1],137[1]|Orb of Translocation/4/2///24[1]|Blasted Lands Portal/4/1///89",
        [14] = "Stormwind City;0;0;2;2;1;m;5|29|57;;Stormwind City/1/1///7[1],95[1],48[1],44[1],55[1],89[1],87[1],71[1],71[7]|The Bravery/2/1//14/38[1]|The Kraken/2/1//14/147[1]|Blasted Lands Portal/4/1///89",
        [15] = "The Exodar;0;0;1;2;1;m;26;;The Exodar/1/1///37[1]|Elune's Blessing/2/1//15/38[1]|Blasted Lands Portal/4/1///89",
        [16] = "The Forbidding Sea;0;0;2;3;128;m;;;",
        [17] = "The Frozen Sea;0;0;4;3;128;f|m;;;",
        [18] = "The Great Sea;0;0;128;3;128;m;;;",
        [19] = "The North Sea;0;0;2;3;128;m;;;",
        [20] = "The Ring of Valor;0;0;1;9;128;m;;;",
        [21] = "The Veiled Sea;0;0;1;3;128;m;;;",
        [22] = "Thunder Bluff;0;0;1;2;2;m;32;;Thunder Bluff/1/2///75[3],80[3],45[2],63[1],10[1],52[2],69[2],45[1],36[2],81[1]|Blasted Lands Portal/4/1///89",
        [23] = "Twisting Nether;0;0;3;3;128;f|m;;;",
        [24] = "Undercity;0;0;2;2;2;m;34;;Undercity/1/2///42[1],56[2],68[2],82[2],74[1],103[1],34[4]|Orb of Translocation/4/2///13[1]|Blasted Lands Portal/4/1///89",
        [26] = "Azuremyst Isle;1;12;1;1;1;m;37|15;;",
        [27] = "Dun Morogh;1;12;2;1;1;m;7|40|61;74|95|58|87;",
        [28] = "Durotar;1;12;1;1;2;m;10|45|36;53;The Iron Eagle/3/2//28/71[4]|The Thundercaller/3/2//28/34|The Mighty Wind/3/2//28/147[6]|The Zephyr/3/2//28/22",
        [29] = "Elwynn Forest;1;12;2;1;1;m;14|44|48|55;95|102;",
        [30] = "Eversong Woods;1;12;2;1;2;m;39|13;;",
        [32] = "Mulgore;1;12;1;1;2;m;22|45;52|69|80;",
        [33] = "Teldrassil;1;12;1;1;1;m;4;;Rut'theran Village/1/1///38[1]|The Moonspray/2/1//33[1]/38[1]",
        [34] = "Tirisfal Glades;1;12;2;1;2;m;24|42|96|65;67;The Purple Princess/3/2//34/71[4]|The Thundercaller/3/2//34/28|The Cloudkisser/3/2//34/148[8]|The Bulwark/1/2///24[1],96[2]",
        [36] = "Azshara;48;55;1;1;128;m;28|53;10|105;Talrendis Point/1/1///38[1],45[3],75[1],93[1],105[1]|Valormok/1/2///10[1],22[1],45[1],53[3],93[2],105[1]",
        [37] = "Bloodmyst Isle;10;20;1;1;1;m;26;;Blood Watch/1/1///15[1]",
        [38] = "Darkshore;10;20;1;1;1;m;53;8|93;Auberdine/1/1///33[1],93[1],36[1],52[1],53[1],69[1],80[1],75[1],8[2]|The Bravery/2/1//38[1]/14|The Moonspray/2/1//38[1]/33[1]|Elune's Blessing/2/1//38[1]/15",
        [39] = "Ghostlands;10;20;2;1;2;m;30|103|164;;Tranquillien/1/2///13[1],103[1],39[2]|Hatchet Hills/1/3///103[1],39[1],137[1]",
        [40] = "Loch Modan;10;20;2;1;1;m;27|58|74;;Thelsamar/1/1///7[1],58[1],68[1]",
        [42] = "Silverpine Forest;10;20;2;1;2;m;34|56|67|49;;The Sepulcher/1/2///24[1],56[2]",
        [44] = "Westfall;10;20;2;1;1;m;29|55|50;71;Sentinel Hill/1/1///14[1],48[1],55[1],71[1],71[7]",
        [45] = "The Barrens;10;25;1;1;2;m;28|32|52|53|63|75|51|60|72|46;80;The Crossroads/1/2///93[2],75[3],80[3],45[2],63[1],10[1],53[3],52[2],22[1],36[2],53[4],81[1],45[3]|Camp Taurajo/1/2///63[1],45[1],22[1]|Ratchet/1/2///53[1],36[1],75[1],10[1],45[1],81[1]|The Maiden's Fancy/2/3//45[3]/71[1]",
        [46] = "Warsong Gulch|WSG;10;-1;1;8;128;s10|r10:19,20:29,30:39,40:49,50:59,60:69,70:79,80:80|m;45|53;;",
        [47] = "Ragefire Chasm|RFC;15;25;1;6;128;b4;10;;",
        [48] = "Redridge Mountains;15;25;2;1;128;m;29|95;77|102;Lakeshire/1/1///14[1],44[1],55[1],95[1]",
        [49] = "Shadowfang Keep|SFK;15;25;2;6;128;b8|d2;42;;",
        [50] = "The Deadmines|VC|DMVC|DM;15;25;2;6;128;b8;44;;",
        [51] = "Wailing Caverns|WC;15;25;1;6;128;b8;45;;",
        [52] = "Stonetalon Mountains;15;27;1;1;128;m;45|53|69;32;Stonetalon Peak/1/1///38[1],53[1],69[1]|Sun Rock Retreat/1/2///22[1],45[1],69[2]",
        [53] = "Ashenvale;15;30;1;1;128;m;38|45|52|36|93|54|46;28|105;Astranaar/1/1///38[1],52[1],53[2],36[1],93[3]|Forest Song/1/1///53[1],36[1],93[3]|Splintertree Post/1/2///10[1],45[1],53[4],36[2]|Zoram'gar Outpost/1/2///45[1],53[3],22[1],52[2]",
        [54] = "Blackfathom Deeps|BFD;19;29;1;6;128;b8;53;;",
        [55] = "Duskwood;20;30;2;1;128;m;29|44|71|102;;Darkshire/1/1///14[1],44[1],48[1],89[1],71[1],71[7]",
        [56] = "Hillsbrad Foothills;20;30;2;1;128;m;42|67|68;82;Southshore/1/1///7[1],58[1],68[1],82[1],96[1]|Tarren Mill/1/2///24[1],42[1],68[2],82[2]",
        [57] = "The Stockade|Stocks;20;30;2;6;128;b5;14;;",
        [58] = "Wetlands;20;30;2;1;128;m;40|68;27;Menethil Harbor/1/1///7[1],40[1],68[1],56[1]|The Lady Mehley/2/1//58[1]/75[1]|Northspear/2/1//58[1]/148[2]",
        [59] = "Arathi Basin|AB;20;-1;2;8;128;s15|r20:29,30:39,40:49,50:59,60:69,70:79,80:80|m;68;;",
        [60] = "Razorfen Kraul|RFK;22;32;1;6;128;b6;45;;",
        [61] = "Gnomeregan|GR|Gnome|Gnomer;23;33;2;6;128;b7;27;;",
        [63] = "Thousand Needles;25;35;1;1;128;m;45|80|81;94|104|75;Freewind Post/1/2///22[1],45[1],45[2],80[3],81[1]",
        [64] = "Scarlet Monastery (Graveyard)|SMG|SM-G;27;37;2;6;128;b2|d8;65;;",
        [65] = "Scarlet Monastery|SM;27;45;2;5;128;;34|64|70|73|76;;",
        [67] = "Alterac Mountains;30;40;2;1;128;m;42|56|82|96|98;34;",
        [68] = "Arathi Highlands;30;40;2;1;128;m;58|56|59;82;Refuge Pointe/1/1///7[1],40[1],58[1],56[1],82[1]|Hammerfall/1/2///24[1],56[2],74[1],82[2]",
        [69] = "Desolace;30;40;1;1;128;m;52|80|85;32;Nijel's Point/1/1///38[1],52[1],75[1],80[1]|Shadowprey Village/1/2///22[1],52[2],80[3]",
        [70] = "Scarlet Monastery (Library)|SML|SM-L;30;40;2;6;128;b2;65;;",
        [71] = "Stranglethorn Vale;30;45;2;1;128;m;55|115;44|89|102;Booty Bay/1/1///14[1],44[1],55[1],71[7]|The Maiden's Fancy/2/3//71[1]/45[3]|Booty Bay/1/2///71[4],77[1],74[1]|Grom'gol Base Camp/1/2///77[1],74[1],71[1]|The Purple Princess/3/2//71[4]/34|The Iron Eagle/3/2//71[4]/28|Rebel Camp/1/1///14[1],44[1],55[1],71[1]",
        [72] = "Razorfen Downs|RFD;32;42;1;6;128;b5;45;;",
        [73] = "Scarlet Monastery (Armory)|SMA|SM-A;32;42;2;6;128;b1;65;;",
        [74] = "Badlands;35;45;2;1;128;m;40|87|78;95|27;Kargath/1/2///24[1],68[2],71[4],71[1],77[1],87[1],95[2]",
        [75] = "Dustwallow Marsh;35;45;1;1;128;m;45|199;63;Theramore Isle/1/1///38[1],45[3],69[1],80[2],81[1],36[1],75[4]|The Lady Mehley/2/1//75[1]/58[1]|Brackenwall Village/1/2///10[1],22[1],45[1],81[1],75[4]|Mudsprocket/1/3///63[1],75[3],80[2],75[1]",
        [76] = "Scarlet Monastery (Cathedral)|SMC|SM-C;35;45;2;6;128;b3;65;;",
        [77] = "Swamp of Sorrows;35;45;2;1;128;m;89|102|88;48;Stonard/1/2///24[1],71[4],71[1],74[1],95[2]",
        [78] = "Uldaman;35;45;2;6;128;b8;74;;",
        [79] = "Maraudon (Purple Crystals)|Mara;39;49;1;6;128;b3;85;;",
        [80] = "Feralas;40;50;1;1;128;m;63|69|100;32|45|104|94;Feathermoon Stronghold/1/1///38[1],69[1],80[2],104[1]|Thalanaar/1/1///75[1],80[1],81[1]|Camp Mojache/1/2///22[1],45[1],63[1],69[2],81[1],104[1]",
        [81] = "Tanaris;40;50;1;1;128;m;63|94|84|135;;Gadgetzan/1/1///75[1],80[2],94[1],104[1],45[3],75[4]|Gadgetzan/1/2///10[1],22[1],45[1],45[2],75[3],80[3],94[1],104[1],45[3],75[4]",
        [82] = "The Hinterlands;40;50;2;1;128;m;67|96;56|68|103;Aerie Peak/1/1///7[1],56[1],68[1],96[1],103[1]|Revantusk Village/1/2///24[1],56[2],68[2],103[1]",
        [83] = "Maraudon (Orange Crystals)|Mara;41;51;1;6;128;b4;85;;",
        [84] = "Zul'Farrak|ZF;41;51;1;6;128;b8|m;81;;",
        [85] = "Maraudon;41;53;1;5;128;;69|83|79|86;;",
        [86] = "Maraudon (Pristine Waters)|Mara;41;53;1;6;128;b4;85;;",
        [87] = "Searing Gorge;43;50;2;1;128;m;74|92;27|95;Thorium Point/1/3///7[1],14[1],40[1],95[1],96[1],74[1],95[2]",
        [88] = "The Temple of Atal'Hakkar|ST|Temple|!Sunken Temple;45;55;2;6;128;b10;77;;",
        [89] = "Blasted Lands;47;55;2;1;128;m;77;71|102;Nethergarde Keep/1/1///14[1],55[1],95[1]|The Dark Portal/4/3///118",
        [90] = "Blackrock Depths (Lower City)|BRD;47;57;2;6;128;b1;91;;",
        [91] = "Blackrock Depths;47;61;2;5;128;;92|90;;",
        [92] = "Blackrock Mountain;47;62;2;5;128;;87|95|91|107;;",
        [93] = "Felwood;48;55;1;1;128;m;53|105|8;38;Talonbranch Glade/1/1///38[1],36[1],8[2],105[1]|Bloodvenom Post/1/2///10[1],45[1],36[2],8[2],105[1]|Emerald Sanctuary/1/3///93[1],93[2]",
        [94] = "Un'Goro Crater;48;55;1;1;128;m;81|104;63|80;Marshal's Refuge/1/3///81[1],104[1]",
        [95] = "Burning Steppes;50;60;2;1;128;m;48|92;74|87|29;Morgan's Vigil/1/1///14[1],48[1],87[1],89[1]|Flame Crest/1/2///77[1],74[1],87[1]",
        [96] = "Western Plaguelands;50;60;2;1;128;m;34|67|82|103|110;;Chillwind Camp/1/1///7[1],56[1],82[1],103[1]|Thondroril River/1/3///103[1],7[1],96[1],82[1],24[1],82[2],34[4]",
        [97] = "Blackrock Depths (Upper City)|BRD;51;61;2;6;128;b19|d6;91;;",
        [98] = "Alterac Valley|AV;51;-1;2;8;128;s40|r51:60,61:70,71:79,80:80|m;67;;",
        [99] = "Dire Maul (East)|DME|DM-E;53;63;1;6;128;b5;100;;",
        [100] = "Dire Maul|DM;53;65;1;5;128;;80|99|109|108;;",
        [101] = "Plaguelands: The Scarlet Enclave;55;58;2;1;128;m;;;",
        [102] = "Deadwind Pass;55;60;2;1;128;m;55|77|159;48|71|89|29;",
        [103] = "Eastern Plaguelands;55;60;2;1;128;m;96|111|39;82;Light's Hope Chapel/1/3///7[1],82[1],96[1],24[1],82[2],39[1],39[2],103[2]|Acherus: The Ebon Hold/1/3/Death Knight//103[1],96[1],82[1],39[1]",
        [104] = "Silithus;55;60;1;1;128;m;94|120|123;63|80;Cenarion Hold/1/3///80[1],80[3],81[1],94[1]",
        [105] = "Winterspring;55;60;1;1;128;m;8|93;36|53;Everlook/1/1///93[1],8[2],36[1]|Everlook/1/2///10[1],93[2],8[2]",
        [106] = "Blackrock Spire|BRS;55;65;2;5;128;;92|107;;",
        [107] = "Blackrock Spire|LBRS|!Lower Blackrock Spire;55;65;2;6;128;b9;106|114;;",
        [108] = "Dire Maul (North)|DMN|DM-N;55;65;1;6;128;b7;100;;",
        [109] = "Dire Maul (West)|DMW|DM-W;55;65;1;6;128;b5;100;;",
        [110] = "Scholomance|Scholo;55;65;2;6;128;b13;96;;",
        [111] = "Stratholme;55;65;2;5;128;;103|112|113;;",
        [112] = "Stratholme (Main Gate)|Strat;55;65;2;6;128;b10;111;;",
        [113] = "Stratholme (Service Entrance)|Strat;55;65;2;6;128;b7;111;;",
        [114] = "Blackrock Spire|UBRS|!Upper Blackrock Spire;56;63;2;7;128;p-1|s10;107;;",
        [115] = "Zul'Gurub|ZG;56;63;2;7;128;p1|s20|m;71;;",
        [116] = "Hellfire Ramparts|HFR|Ramp|Ramps|Ramparts;57;67;3;6;128;b3|h70,75;117;;",
        [117] = "Hellfire Citadel;57;75;3;5;128;;118|116|119|144|160;;",
        [118] = "Hellfire Peninsula;58;63;3;1;128;f|m;124|128|117;;The Dark Portal/4/3///89|Honor Hold/1/1///118[3],118[4],128[1],12[1],118[5]|Shatter Point/1/1///118[2]|Temple of Telhamat/1/1///118[2],124[2]|The Stair of Destiny/1/1///118[2],118[3],118[4],12[1]|Stormwind City Portal/4/1///14|Thrallmar/1/2///118[8],118[9],128[2],12[1],118[5]|Falcon Watch/1/2///118[7],124[3],124[4],133[2]|Spinebreaker Post/1/2///118[7]|The Stair of Destiny/1/2///118[7],118[8],12[1]|Orgrimmar Portal/4/2///10",
        [119] = "The Blood Furnace|BF;59;68;3;6;128;b3|h70,75;117;;",
        [120] = "Ahn'Qiraj|AQ20;60;63;1;7;128;p4|s20|m;104;;",
        [121] = "Blackwing Lair|BWL;60;63;2;7;128;p5|s40;114;;",
        [122] = "Molten Core|MC;60;63;2;7;128;p3|s40;91;;",
        [123] = "Temple of Ahn'Qiraj|AQ40;60;63;2;7;128;p6|s40|m;104;;",
        [124] = "Zangarmarsh;60;64;3;1;128;f|m;118|128|133|136|130;;Orebor Harborage/1/1///136[1],124[2]|Telredor/1/1///124[1],136[1],133[1],118[4],136[2],12[1]|Swamprat Post/1/2///118[8],136[4],136[3],124[4],12[1]|Zabra'jin/1/2///118[8],133[2],124[3],136[3],12[1]",
        [125] = "The Slave Pens|SP;60;69;3;6;128;b3|h70,75|d5;130;;",
        [126] = "The Underbog|UB|Bog;61;70;3;6;128;b5|h70,75;130;;",
        [127] = "Eye of the Storm|EotS|Eye;61;-1;3;8;128;s15|r61:69,70:79,80:80|m;;;",
        [128] = "Terokkar Forest;62;65;3;1;128;f|m;118|124|133|140|131|12;;Allerian Stronghold/1/1///118[2],133[1],140[1],12[1]|Stonebreaker Hold/1/2///118[7],140[2],12[1]",
        [129] = "Mana-Tombs|MT|Tombs;62;70;3;6;128;b3|h70,75;131;;",
        [130] = "Coilfang Reservoir;62;75;3;5;128;;124|125|126|145|161;;",
        [131] = "Ring of Observance|!Auchindoun;62;75;3;5;128;;128|132|141|138|129;;",
        [132] = "Auchenai Crypts|AC|Crypts;63;72;3;6;128;b2|h70,75;131;;",
        [133] = "Nagrand;64;67;3;1;128;f|m;124|128;;Telaar/1/1///124[2],128[1],12[1]|Garadar/1/2///118[8],124[4],12[1]",
        [134] = "Old Hillsbrad Foothills|CoT:Durnholde|Thrall|CoT 1|Old Hillsbrad|Durn|OH|DH|!The Escape from Durnholde Keep;64;73;1;6;128;b3|h70,75|m;135;;",
        [135] = "Caverns of Time;64;80;1;5;128;;81|134|146|158|184;;",
        [136] = "Blade's Edge Mountains;65;68;3;1;128;f|m;124|139|157;;Sylvanaar/1/1///136[2],124[1],124[2],139[2],139[1],136[5]|Toshley's Station/1/1///136[1],139[1]|Thunderlord Stronghold/1/2///136[4],124[3],124[4],136[5],139[1],139[2]|Mok'Nathal Village/1/2///136[3],139[1]|Evergrove/1/3///136[1],136[2],136[3],139[1]",
        [137] = "Isle of Quel'Danas;65;70;2;1;128;m;149|162;;Sun's Reach/1/3///13[1],7[1],39[2],103[1]",
        [138] = "Sethekk Halls|Seth|Sethekk;65;73;3;6;128;b2|h70,75,3;131;;",
        [139] = "Netherstorm;67;70;3;1;128;f|m;136|150;;Area 52/1/3///136[1],136[2],136[3],136[4],139[2],139[3],136[5]|The Stormspire/1/3///136[1],136[3],139[1],139[3]|Cosmowrench/1/3///139[1],139[2]",
        [140] = "Shadowmoon Valley;67;70;3;1;128;f|m;128|156;;Wildhammer Stronghold/1/1///128[1],140[3],140[4]|Shadowmoon Village/1/2///128[2],140[3],140[4]|Altar of Sha'tar/1/3///140[1],140[2]|Sanctum of the Stars/1/3///140[1],140[2]",
        [141] = "Shadow Labyrinth|SL|Lab|Slabs|Shadow Labs;67;75;3;6;128;b4|h70,75;131;;",
        [142] = "The Botanica|Bot;67;75;3;6;128;b5|h70,75;150;;",
        [143] = "The Mechanar|Mech;67;75;3;6;128;b4|h70,75;150;;",
        [144] = "The Shattered Halls|SH;67;75;3;6;128;b3|h70,75;117;;",
        [145] = "The Steamvault|SV|Vaults;67;75;3;6;128;b3|h70,75;130;;",
        [146] = "The Black Morass|CoT:Dark Portal|CoT:DP|BM|CoT 2|!Opening the Dark Portal;68;70;1;6;128;b3|h70,75|m;135;;",
        [147] = "Borean Tundra;68;72;4;1;128;f|m;167|176|155;;Valiance Keep/1/1///147[3],167[2],147[8],155[1],147[9]|The Kraken/2/1//147[1]/14|Fizzcrank Airstrip/1/1///167[2],147[1],147[8],176[1],176[2],147[9]|Bor'gorok Outpost/1/2///147[6],147[8],176[1],176[2]|Taunka'le Village/1/2///167[4],147[4],147[6],147[8],147[9]|Warsong Hold/1/2///167[4],147[4],147[5],147[8],155[1],147[9]|The Mighty Wind/3/2//147[6]/28|Amber Ledge/1/3///147[3],147[1],147[4],147[5],147[6],155[1]|Unu'pe/1/3///147[3],147[1],147[5],147[6]|Walker of Waves/2/3//147[9]/167[7]",
        [148] = "Howling Fjord;68;72;4;1;128;f|m;172|153;;Fort Wildervar/1/1///172[1],148[1],148[4],148[10]|Valgarde/1/1///148[1],148[4],148[10]|Northspear/2/1//148[2]/58[1]|Westguard Keep/1/1///172[1],148[1],167[3],148[10]|Apothecary Camp/1/2///148[6],172[3],148[7],148[10]|Camp Winterhoof/1/2///148[5],172[4],148[7],148[8]|New Agamand/1/2///148[5],148[6],148[8],167[6],148[10]|Vengeance Landing/1/2///172[4],148[6],148[7]|The Cloudkisser/3/2//148[8]/34|Kamagua/1/3///148[2],148[4],148[5],148[7]|Green Island/2/3//148[10]/167[7]",
        [149] = "Magisters' Terrace|MgT|MsT|MrT|QD5|MT;68;75;2;6;128;b3|h70,75;137;;",
        [150] = "Tempest Keep;68;75;3;5;128;;139|143|142|151|163;;",
        [151] = "The Arcatraz|AZ|Arca;68;75;3;6;128;b5|h70,75;150;;",
        [152] = "Utgarde Keep|UK;68;80;4;6;128;b3|h80,83;153;;",
        [153] = "Utgarde Keep;68;83;4;5;128;;148|152|186;;",
        [154] = "The Nexus|Nex|Nexus;69;80;4;6;128;b4|h80,83,5;155;;",
        [155] = "Coldarra|!The Nexus;69;83;4;5;128;;147|154|185|200;;Transitus Shield/1/3///147[1],147[6],147[8]",
        [156] = "Black Temple|BT;70;73;3;7;128;p8|s25;140;;",
        [157] = "Gruul's Lair|GL;70;73;3;7;128;p2|s25;136;;",
        [158] = "Hyjal Summit|HY|MH|!Battle for Mount Hyjal;70;73;1;7;128;p7|s25|m;135;;",
        [159] = "Karazhan|KZ|Kara;70;73;2;7;128;p1|s10;102;;",
        [160] = "Magtheridon's Lair|ML|Mag;70;73;3;7;128;p3|s25;117;;",
        [161] = "Serpentshrine Cavern|SSC;70;73;3;7;128;p5|s25;130;;",
        [162] = "Sunwell Plateau|SWP|QD25;70;73;2;7;128;p9|s25|m;137;;",
        [163] = "The Eye|Eye|TE;70;73;3;7;128;p6|s25;150;;",
        [164] = "Zul'Aman|ZA;70;73;2;7;128;p4|s10|m;39;;",
        [165] = "Azjol-Nerub|AN|Nerub;70;80;4;6;128;b3|h80,83;166;;",
        [166] = "The Pit of Narjun;70;83;4;5;128;;167|165|168;;",
        [167] = "Dragonblight;71;74;4;1;128;f|m;147|174|172|180|166|207|198;;Fordragon Hold/1/1///167[2],167[3],2[1],174[2],207[1]|Stars' Rest/1/1///147[3],167[1],147[1],167[3],167[7],147[9],207[1]|Wintergarde Keep/1/1///172[1],167[1],167[2],148[4],174[2],174[3],167[7],207[1]|Agmar's Hammer/1/2///167[5],147[5],167[6],147[6],167[7],207[1]|Kor'kron Vanguard/1/2///167[4],167[6],2[1],207[1]|Venomspite/1/2///167[4],172[3],167[5],148[7],174[3],167[7]|Moa'ki Harbor/1/3///167[2],167[3],167[4],167[6],2[1],207[1]|Walker of Waves/2/3//167[7]/147[9]|Green Island/2/3//167[7]/148[10]",
        [168] = "Ahn'kahet: The Old Kingdom|AK|Kahet|Old Kingdom;71;80;4;6;128;b4|h80,83,5;166;;",
        [169] = "Isle of Conquest|IoC;71;-1;4;8;128;s40|r71:79,80:80|m;;;",
        [170] = "Strand of the Ancients|SotA;71;-1;4;8;128;s15|r71:79,80:80|m;;;",
        [171] = "Drak'Tharon Keep|DTK|DK;72;80;4;6;128;b4|h80,83;172;;",
        [172] = "Grizzly Hills;73;75;4;1;128;f|m;148|174|167|171;;Amberpine Lodge/1/1///172[2],148[4],167[3]|Westfall Brigade Encampment/1/1///172[1],148[1],174[1],174[4]|Conquest Hold/1/2///172[4],148[5],167[6]|Camp Oneqwah/1/2///172[3],148[6],174[1],174[4]",
        [173] = "The Violet Hold|VH;73;80;4;6;128;b3|h80,83;2;;",
        [174] = "Zul'Drak;74;77;4;1;128;f|m;172|180|167|175;;Argent Stand/1/3///172[2],172[4],174[2],179[1],174[3],174[4]|Ebon Watch/1/3///179[2],180[1],167[3],179[3],180[2],167[6],174[1],2[1],179[1],174[3]|Light's Breach/1/3///172[1],167[3],172[4],172[3],167[6],174[1],174[2],179[1]|Zim'Torga/1/3///172[2],172[4],179[4],174[1],179[1],174[5]|Gundrak/1/3///174[4]",
        [175] = "Gundrak|GD|Gun;74;80;4;6;128;b4|h80,83,5;174;;",
        [176] = "Sholazar Basin;75;78;4;1;128;f|m;147;;Nesingwary Base Camp/1/3///176[2],183[3],147[3]|River's Heart/1/3///176[1],183[3],147[3],147[4]",
        [177] = "Halls of Stone|HoS;75;80;4;6;128;b4|h80,83;178;;",
        [178] = "Ulduar;75;83;4;5;128;;179|177|181|204;;Ulduar/1/3///179[2],179[4],179[3],179[6],179[5],174[4]",
        [179] = "The Storm Peaks;76;80;4;1;128;f|m;180|178;;K3/1/3///179[5],179[3],179[2],174[2],2[1],180[1],180[2]|Frosthold/1/1///179[6],179[1],178[1],183[1]|Grom'arsh Crash-Site/1/2///179[4],179[6],179[1],178[1],183[1]|Camp Tunka'lo/1/2///179[3],179[1],178[1],174[4]|Dun Niffelem/1/3///179[1],178[1],174[4]|Bouldercrag's Refuge/1/3///179[2],179[3],178[1],195[1]",
        [180] = "Crystalsong Forest;77;80;4;1;128;f|m;2|174|167|183|179;;Windrunner's Overlook/1/1///167[1],179[2],167[3],2[1],174[2],179[1]|Sunreaver's Command/1/2///179[3],167[5],2[1],174[2],179[1]",
        [181] = "Halls of Lightning|HoL;77;80;4;6;128;b4|h80,83;178;;",
        [182] = "Hrothgar's Landing;77;80;4;1;128;f|m;183;;",
        [183] = "Icecrown;77;80;4;1;128;f|m;180|195|182|196;;The Argent Vanguard/1/3///183[2],2[1],179[2],179[3],183[4]|Crusaders' Pinnacle/1/3///183[1],2[1],183[3],183[4],195[1]|Death's Rise/1/3///183[2],176[1],176[2],183[4]|The Shadow Vault/1/3///183[1],179[6],183[2],183[3],195[1]",
        [184] = "The Culling of Stratholme|CoS|CoT:CoS|CoT 3|Old Strat|CoT:Strat|Stratholme Past;77;80;1;6;128;b4|h80,83,5|m;135;;",
        [185] = "The Oculus|OCC;77;80;4;6;128;b4|h80,83|m;155;;",
        [186] = "Utgarde Pinnacle|UP;77;80;4;6;128;b4|h80,83;153;;",
        [187] = "Wintergrasp|WG;77;80;4;4;4;f|m;206;;",
        [189] = "Halls of Reflection|HoR;80;80;4;6;128;b3|h80,83;196;;",
        [190] = "Pit of Saron|PoS;80;80;4;6;128;b3|h80,83;196;;",
        [191] = "The Forge of Souls|FoS;80;80;4;6;128;b2|h80,83;196;;",
        [192] = "Trial of the Champion;80;80;4;6;128;b3|h80,83|m;195;;",
        [195] = "Argent Tournament Grounds;80;83;4;5;128;;183|192|203;;Argent Tournament Grounds/1/1///179[6],183[2],2[1],183[4]|Argent Tournament Grounds/1/2///179[6],183[2],2[1],183[4]",
        [196] = "Icecrown Citadel;80;83;4;5;128;;183|197|191|190|189;;",
        [197] = "Icecrown Citadel|ICC|IC;80;83;4;7;128;p8|s10,25|h80,83;196;;",
        [198] = "Naxxramas|Naxx;80;83;4;7;128;p1|s10,25;167;;",
        [199] = "Onyxia's Lair|Ony|Onx|Onyxia;80;83;1;7;128;p5|s10,25;75;;",
        [200] = "The Eye of Eternity|EoE|Eye;80;83;4;7;128;p3|s10,25;155;;",
        [201] = "The Obsidian Sanctum|OS|TOS;80;83;4;7;128;p2|s10,25;207;;",
        [202] = "The Ruby Sanctum|RS|TRS;80;83;4;7;128;p7|s10,25;207;;",
        [203] = "Trial of the Crusader;80;83;4;7;128;p6|s10,25|h80,83|m;195;;",
        [204] = "Ulduar|Uld;80;83;4;7;128;p4|s10,25|m;178;;",
        [205] = "Vault of Archavon|VoA;80;83;4;7;128;p0|s10,25;206;;",
        [206] = "Wintergrasp Fortress;80;83;4;5;128;;187|205;;",
        [207] = "Wyrmrest Temple;80;83;4;5;128;;167|201|202;;Wyrmrest Temple/1/3///167[1],167[2],167[3],167[4],167[5],167[6],2[1],174[2],167[7]",
    };
end--if
